==> quasar-framework-0.17.8.jar: META-INF/resources/webjars/quasar-framework/0.17.8/icons/fontawesome.js <==
export default {
  name: 'fontawesome',
  type: {
    positive: 'fas fa-check',
    negative: 'fas fa-exclamation-triangle',
    info: 'fas fa-info-circle',
    warning: 'fas fa-exclamation'
  },
  arrow: {
    up: 'fas fa-arrow-up',
    right: 'fas fa-arrow-right',
    down: 'fas fa-arrow-down',
    left: 'fas fa-arrow-left'
  },
  chevron: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },

  pullToRefresh: {
    arrow: 'far fa-arrow-alt-circle-down',
    refresh: 'fas fa-sync-alt'
  },
  search: {
    icon: 'fas fa-search',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times'
  },
  carousel: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right', // TODO
    quickNav: 'fas fa-circle',
    thumbnails: 'fas fa-th'
  },
  checkbox: { // TODO
    checked: {
      ios: 'fas fa-check-circle',
      mat: 'fas fa-check-square'
    },
    unchecked: {
      ios: 'far fa-circle',
      mat: 'far fa-square'
    },
    indeterminate: {
      ios: 'fas fa-minus-circle',
      mat: 'fas fa-minus-square'
    }
  },
  chip: {
    close: 'fas fa-times-circle'
  },
  chipsInput: {
    add: 'far fa-paper-plane'
  },
  collapsible: {
    icon: 'fas fa-caret-down'
  },
  datetime: {
    arrowLeft: 'fas fa-chevron-left',
    arrowRight: 'fas fa-chevron-right'
  },
  editor: {
    bold: 'fas fa-bold',
    italic: 'fas fa-italic',
    strikethrough: 'fas fa-strikethrough',
    underline: 'fas fa-underline',
    unorderedList: 'fas fa-list-ul',
    orderedList: 'fas fa-list-ol',
    subscript: 'fas fa-subscript',
    superscript: 'fas fa-superscript',
    hyperlink: 'fas fa-link',
    toggleFullscreen: 'fas fa-expand-arrows-alt',
    quote: 'fas fa-quote-right',
    left: 'fas fa-align-left',
    center: 'fas fa-align-center',
    right: 'fas fa-align-right',
    justify: 'fas fa-align-justify',
    print: 'fas fa-print',
    outdent: 'fas fa-outdent',
    indent: 'fas fa-indent',
    removeFormat: 'fas fa-eraser',
    formatting: 'fas fa-heading',
    fontSize: 'fas fa-text-height',
    align: 'fas fa-align-left',
    hr: 'far fa-minus-square',
    undo: 'fas fa-undo',
    redo: 'fas fa-redo',
    header: 'fas fa-heading',
    code: 'fas fa-code',
    size: 'fas fa-text-height',
    font: 'fas fa-font'
  },
  fab: {
    icon: 'fas fa-plus',
    activeIcon: 'fas fa-times'
  },
  input: {
    showPass: 'fas fa-eye',
    hidePass: 'fas fa-eye-slash',
    showNumber: 'fas fa-calculator',
    hideNumber: 'fas fa-keyboard',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times',
    dropdown: 'fas fa-caret-down'
  },
  pagination: {
    first: 'fas fa-step-backward',
    prev: 'fas fa-chevron-left',
    next: 'fas fa-chevron-right',
    last: 'fas fa-step-forward'
  },
  radio: {
    checked: {
      ios: 'fas fa-check',
      mat: 'fas fa-check-circle'
    },
    unchecked: {
      ios: '',
      mat: 'far fa-circle'
    }
  },
  rating: {
    icon: 'fas fa-star'
  },
  stepper: {
    done: 'fas fa-check',
    active: 'fas fa-pencil-alt',
    error: 'fas fa-exclamation-triangle'
  },
  tabs: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },
  table: {
    arrowUp: 'fas fa-long-arrow-up',
    warning: 'fas fa-exclamation-triangle',
    prevPage: 'fas fa-chevron-left',
    nextPage: 'fas fa-chevron-right'
  },
  tree: {
    icon: 'fas fa-play'
  },
  uploader: {
    done: 'fas fa-check',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times',
    add: 'fas fa-plus-square',
    upload: 'fas fa-cloud-upload-alt',
    expand: 'fas fa-chevron-down',
    file: 'fas fa-file'
  }
}

==> quasar-framework-0.17.12.jar: META-INF/resources/webjars/quasar-framework/0.17.12/icons/fontawesome.js <==
export default {
  name: 'fontawesome',
  type: {
    positive: 'fas fa-check',
    negative: 'fas fa-exclamation-triangle',
    info: 'fas fa-info-circle',
    warning: 'fas fa-exclamation'
  },
  arrow: {
    up: 'fas fa-arrow-up',
    right: 'fas fa-arrow-right',
    down: 'fas fa-arrow-down',
    left: 'fas fa-arrow-left'
  },
  chevron: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },

  pullToRefresh: {
    arrow: 'far fa-arrow-alt-circle-down',
    refresh: 'fas fa-sync-alt'
  },
  search: {
    icon: 'fas fa-search',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times'
  },
  carousel: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right', // TODO
    quickNav: 'fas fa-circle',
    thumbnails: 'fas fa-th'
  },
  checkbox: { // TODO
    checked: {
      ios: 'fas fa-check-circle',
      mat: 'fas fa-check-square'
    },
    unchecked: {
      ios: 'far fa-circle',
      mat: 'far fa-square'
    },
    indeterminate: {
      ios: 'fas fa-minus-circle',
      mat: 'fas fa-minus-square'
    }
  },
  chip: {
    close: 'fas fa-times-circle'
  },
  chipsInput: {
    add: 'far fa-paper-plane'
  },
  collapsible: {
    icon: 'fas fa-caret-down'
  },
  datetime: {
    arrowLeft: 'fas fa-chevron-left',
    arrowRight: 'fas fa-chevron-right'
  },
  editor: {
    bold: 'fas fa-bold',
    italic: 'fas fa-italic',
    strikethrough: 'fas fa-strikethrough',
    underline: 'fas fa-underline',
    unorderedList: 'fas fa-list-ul',
    orderedList: 'fas fa-list-ol',
    subscript: 'fas fa-subscript',
    superscript: 'fas fa-superscript',
    hyperlink: 'fas fa-link',
    toggleFullscreen: 'fas fa-expand-arrows-alt',
    quote: 'fas fa-quote-right',
    left: 'fas fa-align-left',
    center: 'fas fa-align-center',
    right: 'fas fa-align-right',
    justify: 'fas fa-align-justify',
    print: 'fas fa-print',
    outdent: 'fas fa-outdent',
    indent: 'fas fa-indent',
    removeFormat: 'fas fa-eraser',
    formatting: 'fas fa-heading',
    fontSize: 'fas fa-text-height',
    align: 'fas fa-align-left',
    hr: 'far fa-minus-square',
    undo: 'fas fa-undo',
    redo: 'fas fa-redo',
    header: 'fas fa-heading',
    code: 'fas fa-code',
    size: 'fas fa-text-height',
    font: 'fas fa-font'
  },
  fab: {
    icon: 'fas fa-plus',
    activeIcon: 'fas fa-times'
  },
  input: {
    showPass: 'fas fa-eye',
    hidePass: 'fas fa-eye-slash',
    showNumber: 'fas fa-calculator',
    hideNumber: 'fas fa-keyboard',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times',
    dropdown: 'fas fa-caret-down'
  },
  pagination: {
    first: 'fas fa-step-backward',
    prev: 'fas fa-chevron-left',
    next: 'fas fa-chevron-right',
    last: 'fas fa-step-forward'
  },
  radio: {
    checked: {
      ios: 'fas fa-check',
      mat: 'fas fa-check-circle'
    },
    unchecked: {
      ios: '',
      mat: 'far fa-circle'
    }
  },
  rating: {
    icon: 'fas fa-star'
  },
  stepper: {
    done: 'fas fa-check',
    active: 'fas fa-pencil-alt',
    error: 'fas fa-exclamation-triangle'
  },
  tabs: {
    left: 'fas fa-chevron-left',
    right: 'fas fa-chevron-right'
  },
  table: {
    arrowUp: 'fas fa-arrow-up',
    warning: 'fas fa-exclamation-triangle',
    prevPage: 'fas fa-chevron-left',
    nextPage: 'fas fa-chevron-right'
  },
  tree: {
    icon: 'fas fa-play'
  },
  uploader: {
    done: 'fas fa-check',
    clear: 'fas fa-times-circle',
    clearInverted: 'fas fa-times',
    add: 'fas fa-plus-square',
    upload: 'fas fa-cloud-upload-alt',
    expand: 'fas fa-chevron-down',
    file: 'fas fa-file'
  }
}
